@@ -35,32 +35,11 @@ G_BEGIN_DECLS
 /* Whether exit when last window destroyed */
 #define NAUTILUS_PREFERENCES_EXIT_WITH_LAST_WINDOW		"exit-with-last-window"
 
-/* Desktop Background options */
-#define NAUTILUS_PREFERENCES_BACKGROUND_SET                     "background-set"
-#define NAUTILUS_PREFERENCES_BACKGROUND_COLOR                   "background-color"
-#define NAUTILUS_PREFERENCES_BACKGROUND_URI                     "background-uri"
-
-/* Side Pane Background options */
-#define NAUTILUS_PREFERENCES_SIDE_PANE_BACKGROUND_SET           "side-pane-background-set"
-#define NAUTILUS_PREFERENCES_SIDE_PANE_BACKGROUND_COLOR         "side-pane-background-color"
-#define NAUTILUS_PREFERENCES_SIDE_PANE_BACKGROUND_URI           "side-pane-background-uri"
-
-/* Automount options */
-#define NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT			"automount"
-#define NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT_OPEN		"automount-open"
-
-/* Autorun options */
-#define NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER                "autorun-never"
-#define NAUTILUS_PREFERENCES_MEDIA_AUTORUN_X_CONTENT_START_APP  "autorun-x-content-start-app"
-#define NAUTILUS_PREFERENCES_MEDIA_AUTORUN_X_CONTENT_IGNORE     "autorun-x-content-ignore"
-#define NAUTILUS_PREFERENCES_MEDIA_AUTORUN_X_CONTENT_OPEN_FOLDER "autorun-x-content-open-folder"
-
 /* Trash options */
 #define NAUTILUS_PREFERENCES_CONFIRM_TRASH			"confirm-trash"
 #define NAUTILUS_PREFERENCES_ENABLE_DELETE			"enable-delete"
 
 /* Desktop options */
-#define NAUTILUS_PREFERENCES_SHOW_DESKTOP			"show-desktop"
 #define NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR                "desktop-is-home-dir"
 
 /* Display  */
@@ -203,10 +182,18 @@ typedef enum
 #define NAUTILUS_PREFERENCES_DESKTOP_VOLUMES_VISIBLE	   "volumes-visible"
 #define NAUTILUS_PREFERENCES_DESKTOP_NETWORK_VISIBLE       "network-icon-visible"
 #define NAUTILUS_PREFERENCES_DESKTOP_NETWORK_NAME          "network-icon-name"
+#define NAUTILUS_PREFERENCES_DESKTOP_BACKGROUND_FADE       "background-fade"
+
+/* bulk rename utility */
+#define NAUTILUS_PREFERENCES_BULK_RENAME_TOOL              "bulk-rename-tool"
 
 /* Lockdown */
 #define NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE         "disable-command-line"
 
+/* Desktop background */
+#define NAUTILUS_PREFERENCES_SHOW_DESKTOP		   "show-desktop-icons"
+
+
 void nautilus_global_preferences_init                      (void);
 char *nautilus_global_preferences_get_default_folder_viewer_preference_as_iid (void);
 
@@ -216,9 +203,9 @@ GSettings *nautilus_list_view_preferences;
 GSettings *nautilus_compact_view_preferences;
 GSettings *nautilus_desktop_preferences;
 GSettings *nautilus_tree_sidebar_preferences;
-GSettings *nautilus_media_preferences;
 GSettings *nautilus_window_state;
 GSettings *gnome_lockdown_preferences;
+GSettings *gnome_background_preferences;
 
 GConfClient *nautilus_gconf_client;
 
