@@ -35,12 +35,10 @@
 #include <math.h>
 #include "nautilus-icon-dnd.h"
 
-#include "nautilus-debug-log.h"
 #include "nautilus-file-dnd.h"
 #include "nautilus-icon-private.h"
 #include "nautilus-link.h"
 #include "nautilus-metadata.h"
-#include <eel/eel-background.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
@@ -55,11 +53,15 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <eel/eel-canvas-rect-ellipse.h>
+#include <libnautilus-private/nautilus-desktop-background.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-changes-queue.h>
 #include <stdio.h>
 #include <string.h>
 
+#define DEBUG_FLAG NAUTILUS_DEBUG_ICON_CONTAINER
+#include "nautilus-debug.h"
+
 static const GtkTargetEntry drag_types [] = {
 	{ NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE, 0, NAUTILUS_ICON_DND_GNOME_ICON_LIST },
 	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
@@ -186,6 +188,10 @@ canvas_rect_world_to_widget (EelCanvas *canvas,
 			     EelIRect *widget_rect)
 {
 	EelDRect window_rect;
+	GtkAdjustment *hadj, *vadj;
+
+	hadj = gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (canvas));
+	vadj = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (canvas));
 	
 	eel_canvas_world_to_window (canvas,
 				    world_rect->x0, world_rect->y0,
@@ -193,10 +199,10 @@ canvas_rect_world_to_widget (EelCanvas *canvas,
 	eel_canvas_world_to_window (canvas,
 				    world_rect->x1, world_rect->y1,
 				    &window_rect.x1, &window_rect.y1);
-	widget_rect->x0 = (int) window_rect.x0 - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
-	widget_rect->y0 = (int) window_rect.y0 - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
-	widget_rect->x1 = (int) window_rect.x1 - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
-	widget_rect->y1 = (int) window_rect.y1 - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));
+	widget_rect->x0 = (int) window_rect.x0 - gtk_adjustment_get_value (hadj);
+	widget_rect->y0 = (int) window_rect.y0 - gtk_adjustment_get_value (vadj);
+	widget_rect->x1 = (int) window_rect.x1 - gtk_adjustment_get_value (hadj);
+	widget_rect->y1 = (int) window_rect.y1 - gtk_adjustment_get_value (vadj);
 }
 
 static void
@@ -205,8 +211,8 @@ canvas_widget_to_world (EelCanvas *canvas,
 			double *world_x, double *world_y)
 {
 	eel_canvas_window_to_world (canvas,
-				    widget_x + gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas))),
-				    widget_y + gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas))),
+				    widget_x + gtk_adjustment_get_value (gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (canvas))),
+				    widget_y + gtk_adjustment_get_value (gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (canvas))),
 				    world_x, world_y);
 }
 
@@ -386,8 +392,7 @@ get_direct_save_filename (GdkDragContext *context)
 	/* Verify that the file name provided by the source is valid */
 	if (*prop_text == '\0' ||
 	    strchr ((const gchar *) prop_text, G_DIR_SEPARATOR) != NULL) {
-		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-				    "Invalid filename provided by XDS drag site");
+		DEBUG ("Invalid filename provided by XDS drag site");
 		g_free (prop_text);
 		return NULL;
 	}
@@ -425,7 +430,7 @@ set_direct_save_uri (GtkWidget *widget, GdkDragContext *context, NautilusDragInf
 		g_object_unref (child);
 		
 		/* Change the uri property */
-		gdk_property_change (GDK_DRAWABLE (gdk_drag_context_get_source_window (context)),
+		gdk_property_change (gdk_drag_context_get_source_window (context),
 				     gdk_atom_intern (NAUTILUS_ICON_DND_XDNDDIRECTSAVE_TYPE, FALSE),
 				     gdk_atom_intern ("text/plain", FALSE), 8,
 				     GDK_PROP_MODE_REPLACE, (const guchar *) uri,
@@ -1067,18 +1072,23 @@ nautilus_icon_container_receive_dropped_icons (NautilusIconContainer *container,
 	}
 	
 	if (real_action == (GdkDragAction) NAUTILUS_DND_ACTION_SET_AS_BACKGROUND) {
+		NautilusDesktopBackground *background;
+
+		background = nautilus_desktop_background_new (container);
 		selected_item = container->details->dnd_info->drag_info.selection_list->data;
-		eel_background_receive_dropped_background_image
-			(eel_get_widget_background (GTK_WIDGET (container)),
-			 real_action,
-			 selected_item->uri);
+
+		nautilus_desktop_background_receive_dropped_background_image (background,
+									      selected_item->uri);
+
+		g_object_unref (background);
+
 		return;
 	}
 		
 	if (real_action > 0) {
 		eel_canvas_window_to_world (EEL_CANVAS (container),
-					    x + gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (container))),
-					    y + gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (container))),
+					    x + gtk_adjustment_get_value (gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (container))),
+					    y + gtk_adjustment_get_value (gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (container))),
 					    &world_x, &world_y);
 
 		drop_target = nautilus_icon_container_find_drop_target (container, 
@@ -1288,8 +1298,10 @@ drag_begin_callback (GtkWidget      *widget,
 
 	container = NAUTILUS_ICON_CONTAINER (widget);
 
-	start_x = container->details->dnd_info->drag_info.start_x + gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (container)));
-	start_y = container->details->dnd_info->drag_info.start_y + gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (container)));
+	start_x = container->details->dnd_info->drag_info.start_x +
+		gtk_adjustment_get_value (gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (container)));
+	start_y = container->details->dnd_info->drag_info.start_y +
+		gtk_adjustment_get_value (gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (container)));
 
         /* create a pixmap and mask to drag with */
         surface = nautilus_icon_canvas_item_get_drag_surface (container->details->drag_icon->item);
@@ -1327,8 +1339,10 @@ nautilus_icon_dnd_begin_drag (NautilusIconContainer *container,
 	/* Notice that the event is in bin_window coordinates, because of
            the way the canvas handles events.
 	*/
-	dnd_info->drag_info.start_x = start_x - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (container)));
-	dnd_info->drag_info.start_y = start_y - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (container)));	
+	dnd_info->drag_info.start_x = start_x -
+		gtk_adjustment_get_value (gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (container)));
+	dnd_info->drag_info.start_y = start_y -
+		gtk_adjustment_get_value (gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (container)));	
 
 	/* start the drag */
 	context = gtk_drag_begin (GTK_WIDGET (container),
@@ -1343,25 +1357,20 @@ drag_highlight_draw (GtkWidget *widget,
                      cairo_t   *cr,
                      gpointer   user_data)
 {
-	gint x, y, width, height;
+	gint width, height;
 	GdkWindow *window;
 	
-	x = gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (widget)));
-	y = gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (widget)));
-
         window = gtk_widget_get_window (widget);
         width = gdk_window_get_width (window);
         height = gdk_window_get_height (window);
 
-	gtk_paint_shadow (gtk_widget_get_style (widget),
+	gtk_render_frame (gtk_widget_get_style_context (widget),
                           cr,
-			  GTK_STATE_NORMAL, GTK_SHADOW_OUT,
-			  widget, "dnd",
-			  x, y, width, height);
+			  0, 0, width, height);
 
 	cairo_set_line_width (cr, 1.0);
 	cairo_set_source_rgb (cr, 0, 0, 0);
-	cairo_rectangle (cr, x + 0.5, y + 0.5, width - 1, height - 1);
+	cairo_rectangle (cr, 0.5, 0.5, width - 1, height - 1);
 	cairo_stroke (cr);
 
 	return FALSE;
