@@ -40,8 +40,10 @@
 #include "nautilus-program-choosing.h"
 #include "nautilus-desktop-icon-file.h"
 #include "nautilus-global-preferences.h"
-#include "nautilus-debug-log.h"
-#include "nautilus-open-with-dialog.h"
+#include "nautilus-signaller.h"
+
+#define DEBUG_FLAG NAUTILUS_DEBUG_MIME
+#include "nautilus-debug.h"
 
 typedef enum {
 	ACTIVATION_ACTION_LAUNCH_DESKTOP_FILE,
@@ -450,46 +452,6 @@ nautilus_mime_get_applications_for_file (NautilusFile *file)
 	return filter_nautilus_handler (result);
 }
 
-gboolean
-nautilus_mime_has_any_applications_for_file (NautilusFile *file)
-{
-	GList *apps;
-	char *mime_type;
-	gboolean result;
-	char *uri_scheme;
-	GAppInfo *uri_handler;
-
-	mime_type = nautilus_file_get_mime_type (file);
-	
-	apps = g_app_info_get_all_for_type (mime_type);
-
-	uri_scheme = nautilus_file_get_uri_scheme (file);
-	if (uri_scheme != NULL) {
-		uri_handler = g_app_info_get_default_for_uri_scheme (uri_scheme);
-		if (uri_handler) {
-			apps = g_list_prepend (apps, uri_handler);
-		}
-		g_free (uri_scheme);
-	}
-	
-	if (!file_has_local_path (file)) {
-		/* Filter out non-uri supporting apps */
-		apps = filter_non_uri_apps (apps);
-	}
-	apps = filter_nautilus_handler (apps);
-		
-	if (apps) {
-		result = TRUE;
-		g_list_free_full (apps, g_object_unref);
-	} else {
-		result = FALSE;
-	}
-	
-	g_free (mime_type);
-
-	return result;
-}
-
 GAppInfo *
 nautilus_mime_get_default_application_for_files (GList *files)
 {
@@ -622,40 +584,6 @@ nautilus_mime_get_applications_for_files (GList *files)
 	return ret;
 }
 
-gboolean
-nautilus_mime_has_any_applications_for_files (GList *files)
-{
-	GList *l, *sorted_files;
-	NautilusFile *file;
-	gboolean ret;
-
-	g_assert (files != NULL);
-
-	sorted_files = g_list_sort (g_list_copy (files), (GCompareFunc) file_compare_by_mime_type);
-
-	ret = TRUE;
-	for (l = sorted_files; l != NULL; l = l->next) {
-		file = NAUTILUS_FILE (l->data);
-
-		if (l->prev &&
-		    file_compare_by_mime_type (file, l->prev->data) == 0 &&
-		    file_compare_by_parent_uri (file, l->prev->data) == 0) {
-			continue;
-		}
-
-		if (!nautilus_mime_has_any_applications_for_file (file)) {
-			ret = FALSE;
-			break;
-		}
-	}
-
-	g_list_free (sorted_files);
-
-	return ret;
-}
-
-
-
 static void
 trash_or_delete_files (GtkWindow *parent_window,
 		       const GList *files,
@@ -1192,31 +1120,50 @@ get_application_no_mime_type_handler_message (NautilusFile *file, char *uri)
 }
 
 static void
-application_selected_cb (NautilusOpenWithDialog *dialog,
-			 GAppInfo *app,
-			 gpointer user_data)
+open_with_response_cb (GtkDialog *dialog,
+		       gint response_id,
+		       gpointer user_data)
 {
 	GtkWindow *parent_window;
 	NautilusFile *file;
 	GList files;
-
-	parent_window = GTK_WINDOW (user_data);
+	GAppInfo *info;
+	gchar *content_type;
+	ActivateParametersInstall *parameters = user_data;
 	
+	if (response_id != GTK_RESPONSE_OK) {
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+		return;
+	}
+
+	parent_window = parameters->parent_window;
 	file = g_object_get_data (G_OBJECT (dialog), "mime-action:file");
+	info = gtk_app_chooser_get_app_info (GTK_APP_CHOOSER (dialog));
+
+	/* add support for this content type */
+	content_type = nautilus_file_get_mime_type (file);
+	g_app_info_add_supports_type (info, content_type, NULL);
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	g_signal_emit_by_name (nautilus_signaller_get_current (), "mime_data_changed");
 
 	files.next = NULL;
 	files.prev = NULL;
 	files.data = file;
-	nautilus_launch_application (app, &files, parent_window);
+	nautilus_launch_application (info, &files, parent_window);
+
+	g_free (content_type);
+	g_object_unref (info);
 }
 
 static void
 choose_program (GtkDialog *message_dialog, int response, gpointer callback_data)
 {
 	GtkWidget *dialog;
-	char *uri;
-	char *mime_type;
 	NautilusFile *file;
+	GFile *location;
+	ActivateParametersInstall *parameters = callback_data;
 
 	if (response != GTK_RESPONSE_ACCEPT){
 		gtk_widget_destroy (GTK_WIDGET (message_dialog));
@@ -1227,18 +1174,15 @@ choose_program (GtkDialog *message_dialog, int response, gpointer callback_data)
 
 	g_assert (NAUTILUS_IS_FILE (file));
 
+	location = nautilus_file_get_location (file);
 	nautilus_file_ref (file);
-	uri = nautilus_file_get_uri (file);
-	mime_type = nautilus_file_get_mime_type (file);
 
-	dialog = nautilus_open_with_dialog_new (uri, mime_type, NULL);
+	dialog = gtk_app_chooser_dialog_new (parameters->parent_window,
+					     0, location);
 	g_object_set_data_full (G_OBJECT (dialog), 
 				"mime-action:file",
 				nautilus_file_ref (file),
 				(GDestroyNotify)nautilus_file_unref);
-	
-	gtk_window_set_screen (GTK_WINDOW (dialog), 
-			       gtk_widget_get_screen (GTK_WIDGET (callback_data)));
 
 	/* Destroy the message dialog after ref:ing the file */
 	gtk_widget_destroy (GTK_WIDGET (message_dialog));
@@ -1246,13 +1190,12 @@ choose_program (GtkDialog *message_dialog, int response, gpointer callback_data)
 	gtk_widget_show (dialog);
 
 	g_signal_connect_object (dialog, 
-				 "application_selected", 
-				 G_CALLBACK (application_selected_cb),
-				 callback_data,
+				 "response", 
+				 G_CALLBACK (open_with_response_cb),
+				 parameters,
 				 0);
-			  
- 	g_free (uri);
-	g_free (mime_type);
+
+	g_object_unref (location);
 	nautilus_file_unref (file);	
 }
 
@@ -1304,7 +1247,7 @@ show_unhandled_type_error (ActivateParametersInstall *parameters)
 	gtk_widget_show (GTK_WIDGET (dialog));
 	
 	g_signal_connect (dialog, "response",
-			  G_CALLBACK (choose_program), parameters->parent_window);
+			  G_CALLBACK (choose_program), parameters);
 
 	g_free (error_message);
 	g_free (mime_type);
@@ -1382,8 +1325,7 @@ search_for_application_mime_type (ActivateParametersInstall *parameters_install,
 			   (GAsyncReadyCallback) search_for_application_dbus_call_notify_cb,
 			   parameters_install);
 
-	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-	                    "InstallMimeType method invoked for %s", mime_type);
+	DEBUG ("InstallMimeType method invoked for %s", mime_type);
 }
 
 static void
@@ -1560,9 +1502,7 @@ untrusted_launcher_response_callback (GtkDialog *dialog,
 	case RESPONSE_RUN:
 		screen = gtk_widget_get_screen (GTK_WIDGET (parameters->parent_window));
 		uri = nautilus_file_get_uri (parameters->file);
-		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-				    "directory view activate_callback launch_desktop_file window=%p: %s",
-				    parameters->parent_window, uri);
+		DEBUG ("Launching untrusted launcher %s", uri);
 		nautilus_launch_desktop_file (screen, uri, NULL,
 					      parameters->parent_window);
 		g_free (uri);
@@ -1643,9 +1583,7 @@ activate_desktop_file (ActivateParameters *parameters,
 	}
 	
 	uri = nautilus_file_get_uri (file);
-	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-			    "directory view activate_callback launch_desktop_file window=%p: %s",
-			    parameters->parent_window, uri);
+	DEBUG ("Launching trusted launcher %s", uri);
 	nautilus_launch_desktop_file (screen, uri, NULL,
 				      parameters->parent_window);
 	g_free (uri);
@@ -1752,9 +1690,7 @@ activate_files (ActivateParameters *parameters)
 		quoted_path = g_shell_quote (executable_path);
 		name = nautilus_file_get_name (file);
 
-		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-				    "directory view activate_callback launch_file window=%p: %s",
-				    parameters->parent_window, quoted_path);
+		DEBUG ("Launching file name %s, path %s", name, quoted_path);
 
 		nautilus_launch_application_from_command (screen, name, quoted_path, FALSE, NULL);
 		g_free (name);
@@ -1773,9 +1709,7 @@ activate_files (ActivateParameters *parameters)
 		quoted_path = g_shell_quote (executable_path);
 		name = nautilus_file_get_name (file);
 
-		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-				    "directory view activate_callback launch_in_terminal window=%p: %s",
-				    parameters->parent_window, quoted_path);
+		DEBUG ("Launching in terminal file name %s, quoted path %s", name, quoted_path);
 
 		nautilus_launch_application_from_command (screen, name, quoted_path, TRUE, NULL);
 		g_free (name);
@@ -2357,9 +2291,7 @@ nautilus_mime_activate_files (GtkWindow *parent_window,
 		return;
 	}
 
-	nautilus_debug_log_with_file_list (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER, files,
-					   "nautilus_mime_activate_files window=%p",
-					   parent_window);
+	DEBUG_FILES (files, "Calling activate_files() with files:");
 
 	parameters = g_new0 (ActivateParameters, 1);
 	parameters->slot_info = slot_info;
