@@ -45,7 +45,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #include <signal.h>
-#include <libgnomeui/gnome-desktop-thumbnail.h>
+#include <libgnome-desktop/gnome-desktop-thumbnail.h>
 
 #include "nautilus-file-private.h"
 
@@ -425,8 +425,9 @@ get_pixbuf_from_data (const unsigned char *buffer,
 	GError *error;
 
 	if (thumbnail_icon_size == 0) {
-		eel_preferences_add_auto_integer (NAUTILUS_PREFERENCES_ICON_VIEW_THUMBNAIL_SIZE,
-						  &thumbnail_icon_size);
+		eel_g_settings_add_auto_int (nautilus_icon_view_preferences,
+					     NAUTILUS_PREFERENCES_ICON_VIEW_THUMBNAIL_SIZE,
+					     &thumbnail_icon_size);
 	}
 
 	loader = gdk_pixbuf_loader_new ();
@@ -715,7 +716,7 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 {
 	NautilusFile *file;
 
-	GDK_THREADS_ENTER ();
+	gdk_threads_enter ();
 
 	file = nautilus_file_get_by_uri ((char *) image_uri);
 #ifdef DEBUG_THUMBNAILS
@@ -731,7 +732,7 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 	}
 	g_free (image_uri);
 
-	GDK_THREADS_LEAVE ();
+	gdk_threads_leave ();
 
 	return FALSE;
 }
