@@ -81,15 +81,6 @@ nautilus_notebook_class_init (NautilusNotebookClass *klass)
 	container_class->remove = nautilus_notebook_remove;
 
 	notebook_class->insert_page = nautilus_notebook_insert_page;
-	
-	gtk_rc_parse_string ("style \"nautilus-tab-close-button-style\"\n"
-			     "{\n"
-			       "GtkWidget::focus-padding = 0\n"
-			       "GtkWidget::focus-line-width = 0\n"
-			       "xthickness = 0\n"
-			       "ythickness = 0\n"
-			     "}\n"
-			     "widget \"*.nautilus-tab-close-button\" style \"nautilus-tab-close-button-style\"");
 
 	signals[TAB_CLOSE_REQUEST] =
 		g_signal_new ("tab-close-request",
@@ -152,10 +143,11 @@ find_tab_num_at_pos (NautilusNotebook *notebook, gint abs_x, gint abs_y)
 	int page_num = 0;
 	GtkNotebook *nb = GTK_NOTEBOOK (notebook);
 	GtkWidget *page;
+	GtkAllocation allocation;
 
 	tab_pos = gtk_notebook_get_tab_pos (GTK_NOTEBOOK (notebook));
 
-	if (GTK_NOTEBOOK (notebook)->first_tab == NULL)
+	if (gtk_notebook_get_n_pages (nb) == 0)
 	{
 		return AFTER_ALL_TABS;
 	}
@@ -176,17 +168,18 @@ find_tab_num_at_pos (NautilusNotebook *notebook, gint abs_x, gint abs_y)
 		tab = gtk_notebook_get_tab_label (nb, page);
 		g_return_val_if_fail (tab != NULL, -1);
 
-		if (!GTK_WIDGET_MAPPED (GTK_WIDGET (tab)))
+		if (!gtk_widget_get_mapped (GTK_WIDGET (tab)))
 		{
 			page_num++;
 			continue;
 		}
 
-		gdk_window_get_origin (GDK_WINDOW (tab->window),
+		gdk_window_get_origin (gtk_widget_get_window (tab),
 				       &x_root, &y_root);
+		gtk_widget_get_allocation (tab, &allocation);
 
-		max_x = x_root + tab->allocation.x + tab->allocation.width;
-		max_y = y_root + tab->allocation.y + tab->allocation.height;
+		max_x = x_root + allocation.x + allocation.width;
+		max_y = y_root + allocation.y + allocation.height;
 
 		if (((tab_pos == GTK_POS_TOP)
 		     || (tab_pos == GTK_POS_BOTTOM))
@@ -237,10 +230,32 @@ button_press_cb (NautilusNotebook *notebook,
 static void
 nautilus_notebook_init (NautilusNotebook *notebook)
 {
+	static const gchar css_custom[] =
+	  "#nautilus-tab-close-button {"
+	  "  -GtkWidget-focus-padding : 0;"
+	  "  -GtkWidget-focus-line-width: 0;"
+	  "  xthickness: 0;"
+	  "  ythickness: 0;"
+	  "}";
+
+	GError *error = NULL;
+	GtkCssProvider *provider = gtk_css_provider_new ();
+	gtk_css_provider_load_from_data (provider, css_custom, -1, &error);
+
+	if (error != NULL) {
+		g_warning ("Can't parse NautilusNotebook's CSS custom description: %s\n", error->message);
+		g_error_free (error);
+	} else {
+		gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (notebook)),
+						GTK_STYLE_PROVIDER (provider),
+						GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	}
+
+	g_object_unref (provider);
+
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
-	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_BOTTOM);
 
 	g_signal_connect (notebook, "button-press-event",
 			  (GCallback)button_press_cb, NULL);
@@ -317,10 +332,10 @@ nautilus_notebook_sync_tab_label (NautilusNotebook *notebook,
 		 * so it covers all of the tab label.
 		 */
 		location_name = g_file_get_parse_name (slot->location);
-		gtk_widget_set_tooltip_text (label->parent, location_name);
+		gtk_widget_set_tooltip_text (gtk_widget_get_parent (label), location_name);
 		g_free (location_name);
 	} else {
-		gtk_widget_set_tooltip_text (label->parent, NULL);
+		gtk_widget_set_tooltip_text (gtk_widget_get_parent (label), NULL);
 	}
 }
 
