@@ -37,14 +37,11 @@
 #include "nautilus-desktop-window.h"
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-location-dialog.h"
-#include "nautilus-main.h"
 #include "nautilus-query-editor.h"
 #include "nautilus-search-bar.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-zoom-control.h"
-#include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkkeysyms.h>
@@ -56,7 +53,6 @@
 #include <libnautilus-private/nautilus-ui-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
-#include <libnautilus-private/nautilus-horizontal-splitter.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
@@ -533,7 +529,7 @@ location_menu_item_activated_callback (GtkWidget *menu_item,
 		nautilus_window_slot_open_location_with_selection
 			(slot, dest, selection, close_behind);
 
-		eel_g_object_list_free (selection);
+		g_list_free_full (selection, g_object_unref);
 	}
 
 	if (event != NULL) {
@@ -937,7 +933,6 @@ static const char* icon_entries[] = {
 static void
 nautilus_spatial_window_init (NautilusSpatialWindow *window)
 {
-	GtkRcStyle *rc_style;
 	GtkWidget *arrow;
 	GtkWidget *hbox, *vbox;
 	GtkActionGroup *action_group;
@@ -983,11 +978,6 @@ nautilus_spatial_window_init (NautilusSpatialWindow *window)
 			  window);
 	gtk_button_set_relief (GTK_BUTTON (window->details->location_button),
 			       GTK_RELIEF_NORMAL);
-	rc_style = gtk_widget_get_modifier_style (window->details->location_button);
-	rc_style->xthickness = 0;
-	rc_style->ythickness = 0;
-	gtk_widget_modify_style (window->details->location_button, 
-				 rc_style);
 
 	gtk_widget_show (window->details->location_button);
 	hbox = gtk_hbox_new (FALSE, 3);
